#!/usr/bin/env node
"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.wrapKustomizeIntoHelm = wrapKustomizeIntoHelm;
const cp = __importStar(require("child_process"));
const dotenv = __importStar(require("dotenv"));
const path = __importStar(require("path"));
const yaml_1 = require("yaml");
const lang_1 = require("./lang");
const kustomize_files_1 = require("./templates/kustomize-files");
const overlays_files_1 = require("./templates/overlays-files");
const utils_1 = require("./utils");
/**
 * Wraps Kustomize into a Helm chart
 * @param {WrapKustomizeOptions} options - The options for wrapping Kustomize into a Helm chart
 * @returns {Promise<void>} - A promise that resolves when the Kustomize is wrapped into a Helm chart
 */
function wrapKustomizeIntoHelm(_a) {
    return __awaiter(this, arguments, void 0, function* ({ cwd, targetFolder, directory, kustomizeOptions, chartName, chartVersion, chartDescription = '', fs = utils_1.fsDefault, execSync = cp.execSync, parametrize = [], }) {
        const kustomizeDir = /^\./.test(directory) ? path.resolve(cwd, directory) : directory;
        const tempFolder = path.join(kustomizeDir, '.helmify-kustomize-build');
        const targetTemplatesFolder = path.join(cwd, targetFolder, 'templates');
        copyFolder(fs, kustomizeDir, tempFolder, (src) => !src.includes('.helmify-kustomize-build'));
        const overlaysDir = path.join(tempFolder, 'overlays');
        const overlays = fs.readdirSync(overlaysDir).filter((file) => fs.statSync(path.join(overlaysDir, file)).isDirectory());
        const kustomizeCliOptions = Object.entries(kustomizeOptions)
            .map(([key, value]) => `${key} ${value}`)
            .join(' ');
        const parametrizeResults = [];
        const mapRandomStringsToParametrize = {};
        parametrize.forEach((param) => {
            const [valuesProp, filePath] = param.split('=');
            const envPath = path.join(tempFolder, filePath);
            const before = dotenv.parse(fs.readFileSync(envPath, 'utf8'));
            const after = Object.assign({}, before);
            Object.keys(after).forEach((key) => {
                const id = (0, utils_1.randomString)();
                after[key] = id;
                mapRandomStringsToParametrize[id] = { valuesProp, before, after, key };
                parametrizeResults.push({ valuesProp, before, after, key });
            });
            fs.writeFileSync(envPath, Object.entries(after).map(([k, v]) => `${k}=${v}`).join('\n'), 'utf8');
        });
        const paramsRegex = new RegExp(Object.keys(mapRandomStringsToParametrize).join('|'), 'g');
        const replaceParams = (content) => content.replace(paramsRegex, (match) => {
            const param = mapRandomStringsToParametrize[match];
            if (!param)
                return match;
            return `{{ .Values.${param.valuesProp}.${param.key} }}`;
        });
        const kustomizeManifestsResults = yield Promise.all(overlays.map((overlay) => __awaiter(this, void 0, void 0, function* () {
            const overlayPath = path.join(overlaysDir, overlay);
            const output = execSync(`kustomize build ${overlayPath} ${kustomizeCliOptions}`, { encoding: 'utf-8', cwd: tempFolder });
            return { overlay: `overlays/${overlay}`, content: replaceParams(output) };
        })));
        const resultContent = (0, overlays_files_1.overlaysResults)(kustomizeManifestsResults);
        fs.mkdirSync(targetTemplatesFolder, { recursive: true });
        fs.writeFileSync(path.join(targetTemplatesFolder, '_overlays-content.tpl'), resultContent, 'utf8');
        const kustomizationFiles = getKustomizationFiles(fs, kustomizeDir);
        const kustomizeHelperContent = (0, kustomize_files_1.kustomizeFiles)(kustomizationFiles);
        fs.writeFileSync(path.join(targetTemplatesFolder, '_kustomize-files.tpl'), kustomizeHelperContent, 'utf8');
        // copy from static to targetTemplatesFolder
        copyFolder(fs, path.join(__dirname, 'static'), targetTemplatesFolder);
        const groups = (0, utils_1.groupBy)(parametrizeResults, (o) => o.valuesProp);
        const valuesYamlObj = Object.fromEntries(Array.from(groups.entries()).map(([key, value]) => [key, Object.fromEntries(value.map(o => [o.key, o.before[o.key]]))]));
        const prefixDocs = (0, lang_1.trimIndent)(`|# globals:
    |#  namespace: "namespace"
    |#  namePrefix: "namePrefix"
    |#  nameSuffix: "nameSuffix"
    |#  nameReleasePrefix: "nameReleasePrefix"
    |#  labels:
    |#    key: "label"
    |#  annotations:
    |#    key: "annotation"
    `);
        fs.writeFileSync(path.join(cwd, targetFolder, 'values.yaml'), prefixDocs + "\n" + (0, lang_1.trimIndent)((0, yaml_1.stringify)(Object.assign({ overlay: '' }, valuesYamlObj))), 'utf8');
        fs.writeFileSync(path.join(cwd, targetFolder, 'Chart.yaml'), (0, lang_1.trimIndent)(`|apiVersion: v2\n|name: ${chartName}\n|version: ${chartVersion}\n|description: ${chartDescription}`), 'utf8');
    });
}
// Utility Functions
function copyFolder(fs, source, target, filter = () => true) {
    if (!fs.existsSync(source))
        throw new Error(`Source folder does not exist: ${source}`);
    if (!fs.existsSync(target))
        fs.mkdirSync(target, { recursive: true });
    fs.readdirSync(source).forEach((entry) => {
        const sourcePath = path.join(source, entry);
        const targetPath = path.join(target, entry);
        if (!filter(sourcePath, targetPath))
            return;
        const stats = fs.statSync(sourcePath);
        stats.isDirectory() ? copyFolder(fs, sourcePath, targetPath, filter) : fs.copyFileSync(sourcePath, targetPath);
    });
}
/**
 * Retrieves Kustomize files from a given directory
 * @param {FS} fs - The filesystem interface
 * @param {string} folder - The directory to scan for Kustomize files
 * @returns {Array<{ folder: string; filePath: string; content: string }>} An array of Kustomize files
 */
function getKustomizationFiles(fs, folder) {
    const result = [];
    const scanDirectory = (directory) => {
        fs.readdirSync(directory).forEach((file) => {
            const filePath = path.join(directory, file);
            if (fs.statSync(filePath).isDirectory()) {
                scanDirectory(filePath);
            }
            else if (file === 'kustomization.yaml' || file === 'kustomization.yml') {
                result.push({
                    folder: path.relative(folder, directory),
                    filePath: path.relative(folder, filePath),
                    content: fs.readFileSync(filePath, 'utf8'),
                });
            }
        });
    };
    scanDirectory(folder);
    return result;
}
