"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = __importStar(require("path"));
const yaml_1 = require("yaml");
const index_1 = require("./index");
const utils_1 = require("./utils");
const { execSync } = require('child_process');
describe('wrapKustomizeIntoHelm', () => {
    beforeEach(() => {
        jest.clearAllMocks();
    });
    it('should create helm chart with basic configuration', () => __awaiter(void 0, void 0, void 0, function* () {
        const options = {
            cwd: './kustomize-tests',
            targetFolder: '../test-results/simplest-test',
            directory: './simplest-test',
            kustomizeOptions: {},
            chartName: 'test-chart',
            chartVersion: '1.0.0',
            chartDescription: 'Test Chart',
            fs: utils_1.fsDefault,
            execSync: execSync,
        };
        yield (0, index_1.wrapKustomizeIntoHelm)(options);
        const result = execSync(`helm template test-chart . --set overlay="overlays/dev"`, {
            cwd: path.join(options.cwd, options.targetFolder),
        });
        const yamls = result.toString().split(/---\n#.+\n/g).filter((s) => s.trim() !== '');
        console.log(yamls);
        expect(yamls.length).toBe(2);
        const serviceYaml = (0, yaml_1.parse)(yamls[0]);
        expect(serviceYaml.metadata.name).toBe('nginx-service');
        expect(serviceYaml.spec.ports[0].port).toBe(80);
        expect(serviceYaml.spec.ports[0].protocol).toBe('TCP');
        expect(serviceYaml.spec.ports[0].targetPort).toBe(80);
        const deploymentYaml = (0, yaml_1.parse)(yamls[1]);
        expect(deploymentYaml.metadata.name).toBe('nginx-deployment');
        expect(deploymentYaml.spec.replicas).toBe(3);
        expect(deploymentYaml.spec.selector.matchLabels.app).toBe('nginx');
        expect(deploymentYaml.spec.template.spec.containers[0].image).toBe('nginx:1.14.2');
        expect(deploymentYaml.spec.template.spec.containers[0].ports[0].containerPort).toBe(80);
    }));
    it('should create helm chart with parametrizing', () => __awaiter(void 0, void 0, void 0, function* () {
        const options = {
            cwd: './kustomize-tests',
            targetFolder: '../test-results/replacements-vars',
            directory: './replacements-vars',
            kustomizeOptions: {},
            chartName: 'test-chart',
            chartVersion: '1.0.0',
            chartDescription: 'Test Chart',
            fs: utils_1.fsDefault,
            execSync: execSync,
            parametrize: ['devEnv=overlays/dev/.env', 'baseEnv=base/.env'],
        };
        yield (0, index_1.wrapKustomizeIntoHelm)(options);
        const result = execSync(`helm template test-chart . --set overlay="overlays/dev"`, {
            cwd: path.join(options.cwd, options.targetFolder),
        });
        const yamls = result.toString().split(/---\n#.+\n/g).filter((s) => s.trim() !== '');
        expect(yamls.length).toBe(4);
        const objects = yamls.map((yaml) => (0, yaml_1.parse)(yaml));
        const baseValuesFile = objects.find((o) => o.kind === 'ConfigMap' && o.metadata.name.includes('base-environment-values'));
        expect(baseValuesFile.data.IMAGE_URL).toBe('nginx:1.14.2');
        expect(baseValuesFile.data.TEST).toBe(null);
        const devEnvFile = objects.find((o) => o.kind === 'ConfigMap' && o.metadata.name.includes('dev-environment-values'));
        expect(devEnvFile.data.APP_NAME).toBe('my-app');
    }));
});
