"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.kustomizeFiles = void 0;
const yaml_1 = require("yaml");
const lang_1 = require("../lang");
/**
 * Generates a Helm template helper that contains all Kustomize configuration files
 * @param {KustomizeFile[]} files - Array of Kustomize configuration files
 * @returns {string} A Helm template string containing the Kustomize configurations
 */
const kustomizeFiles = (files) => {
    return (0, lang_1.trimIndent)(`|{{- define "kustomizeFiles" }}
        |${(0, yaml_1.stringify)({
        manifests: files.map(({ folder, filePath, content }) => {
            const manifest = (0, yaml_1.parse)(content);
            return {
                metadata: {
                    folder: folder,
                    filePath: filePath,
                },
                spec: manifest,
            };
        }),
    })}
        |{{- end }}`);
};
exports.kustomizeFiles = kustomizeFiles;
