"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.singleOverlay = void 0;
const lang_1 = require("../lang");
/**
 * Generates a Helm template string for a single Kustomize overlay
 * @param {string} overlay - The path to the overlay directory relative to the base
 * @param {string} content - The raw YAML content generated from building the overlay
 * @returns {string} A Helm template string containing the overlay configuration
 */
const singleOverlay = (overlay, content) => {
    const manifests = content
        .split('---')
        .map((manifest) => manifest.trim())
        .filter((manifest) => manifest.length > 0);
    return (0, lang_1.trimIndent)(`|{{- if eq .Values.overlay "${overlay}" }}
        |manifests:
        |${manifests
        .map((manifest) => (0, lang_1.trimIndent)(`|  - spec: 
                    |${(0, lang_1.indentYaml)(manifest, 6)}`))
        .join('\n')}
        |{{- else}}
        |{{- end }}`);
};
exports.singleOverlay = singleOverlay;
